class hadoop {

exec { "download_hadoop":
# Download from nearby mirror, otherwise task can time-out
command => "wget -O /tmp/hadoop.tar.gz http://apache.mirror.amaze.com.au/hadoop/common/hadoop-2.7.3/hadoop-2.7.3.tar.gz",
# command => "wget -O /tmp/hadoop.tar.gz http://www-eu.apache.org/dist/hadoop/common/hadoop-2.7.3/hadoop-2.7.3.tar.gz",
path => $path,
user => $user,
group => $user,
unless => "ls ${install_dir} | grep hadoop-2.7.3",
require => Package["openjdk-7-jdk"]
}

exec { "unpack_hadoop" :
  command => "tar -zxf /tmp/hadoop.tar.gz -C ${install_dir}",
  path => $path,
  creates => "${hadoop_home}-2.7.3",
  require => Exec["download_hadoop"]
}

exec { 'chown':
  command => "/bin/chown -R ${user}:${group} /opt/hadoop-2.7.3",
  path => '/bin',
  user => 'root',
  require => Exec["unpack_hadoop"]
}

file {
  "${hadoop_home}-2.7.3/etc/hadoop/slaves":
  content => template('hadoop/slaves'),
  mode => 644,
  owner => $user,
  group => $group,
  require => Exec["unpack_hadoop"]
 }
 
file {
  "${hadoop_home}-2.7.3/etc/hadoop/masters":
  content => template('hadoop/masters'),
  mode => 644,
  owner => $user,
  group => $group,
  require => Exec["unpack_hadoop"]
 }

file {
  "${hadoop_home}-2.7.3/etc/hadoop/core-site.xml":
  content => template('hadoop/core-site.xml'),
  mode => 644,
  owner => $user,
  group => $group,
  require => Exec["unpack_hadoop"]
 }
 
file {
  "${hadoop_home}-2.7.3/etc/hadoop/mapred-site.xml":
  content => template('hadoop/mapred-site.xml'),
  mode => 644,
  owner => $user,
  group => $group,
  require => Exec["unpack_hadoop"]
 }
 
 file {
  "${hadoop_home}-2.7.3/etc/hadoop/hdfs-site.xml":
  content => template('hadoop/hdfs-site.xml'),
  mode => 644,
  owner => $user,
  group => $group,
  require => Exec["unpack_hadoop"]
 }
 
file {
  "${hadoop_home}-2.7.3/etc/hadoop/hadoop-env.sh":
  content => template('hadoop/hadoop-env.sh'),
  mode => 644,
  owner => $user,
  group => $group,
  require => Exec["unpack_hadoop"]
 }

file{
   [ "${hadoop_home}-2.7.3/hadoop_store",
     "${hadoop_home}-2.7.3/hadoop_store/hdfs",
     "${hadoop_home}-2.7.3/hadoop_store/hdfs/namenode",
     "${hadoop_home}-2.7.3/hadoop_store/hdfs/datanode"]:
   ensure => 'directory',
   owner => "${user}",
   group => "${group}",
   mode => 755,
   require => Exec["unpack_hadoop"]
  }

file_line { "add_hadoop_home":
    ensure => present,
    path => "/home/${user}/.bashrc",
    line => "export HADOOP_HOME=\"${hadoop_home}-2.7.3\"",
    require => [  Exec["unpack_hadoop"], File["/home/${user}"] ]	
}

file_line { "add_hadoop_confdir":
    ensure => present,
    path => "/home/${user}/.bashrc",
    line => 'export HADOOP_CONF_DIR="$HADOOP_HOME/etc/hadoop"',
    require => [  Exec["unpack_hadoop"], File["/home/${user}"] ]	
}

file_line { "add_hadoop_setup":
    ensure => present,
    path => "/home/${user}/.bashrc",
    line => 'source "$HADOOP_HOME/etc/hadoop/hadoop-env.sh"',
    require => [  Exec["unpack_hadoop"], File["/home/${user}"] ]
}

file_line { "add_hadoop_path":
    ensure => present,
    path => "/home/${user}/.bashrc",
    line => 'export PATH="$PATH:$HADOOP_HOME/bin:$HADOOP_HOME/sbin"',
    require => [  Exec["unpack_hadoop"], File["/home/${user}"] ]	
}

}

